@@ -10,7 +10,7 @@ def load_pipeline_config(context: Context, config: t.Dict[str, str]):
 
 
 def load_test_file(
-    context: Context, local_path: os.PathLike, datalake_path: str, **kwargs
+    context: Context, local_path: os.PathLike, datalake_path: str, mode: str = 'r', **kwargs
 ) -> File:
     """Load a local file into the testing data lake, for use in an
     integration test.
@@ -18,7 +18,7 @@ def load_test_file(
     >>> load_test_file(ctx, base_dir / 'setup.py', '/setup.py', file_category='RAW')
     {'type': 's3', 'bucket': 'fake-unittest-bucket', 'fileKey': '/setup.py'}
     """
-    with open(local_path) as f:
+    with open(local_path, mode=mode) as f:
         return context.write_file(f.read(), datalake_path, **kwargs)
 
 
